@@ -66,7 +66,7 @@ def cube_root(a):
     return float(a ** (1 / 3))
 
 
-def calc_lcm(a, b):
+def lcm(a, b):
     """
     Calculate The Least Common Multiple of two numbers.
 
@@ -88,7 +88,7 @@ def calc_lcm(a, b):
     return float(lcm)
 
 
-def calc_gcd(a, b):
+def gcd(b, a):
     """
     Calculate the Greatest Common Divisor of two numbers.
 
@@ -96,14 +96,10 @@ def calc_gcd(a, b):
     :param b: Second Number
     :return: Greatest Common Divisor
     """
-    if a > b:
-        smaller = b
+    if a == 0:
+        return b
     else:
-        smaller = a
-    for i in range(1, smaller + 1):
-        if (a % i == 0) and (b % i == 0):
-            gcd = i
-    return float(gcd)
+        return gcd(a, b % a)
 
 
 def deg_to_rad(deg):
